@@ -8,7 +8,7 @@ use Data::MARC::Leader;
 use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -104,7 +104,7 @@ MARC::Leader - MARC leader class.
  use MARC::Leader;
 
  my $obj = MARC::Leader->new(%params);
- my $leader_obj = $obj->parse(leader_str);
+ my $leader_obj = $obj->parse($leader_str);
  my $leader_str = $obj->serialize($leader_obj);
 
 =head1 METHODS
@@ -119,7 +119,7 @@ Returns instance of object.
 
 =head2 C<parse>
 
- my $leader_obj = $obj->parse(leader_str);
+ my $leader_obj = $obj->parse($leader_str);
 
 Parse MARC leader string to object.
 
@@ -200,6 +200,49 @@ Returns string.
 
 =head1 EXAMPLE2
 
+=for comment filename=parse_marc_leader_and_print.pl
+
+ use strict;
+ use warnings;
+
+ use MARC::Leader;
+ use MARC::Leader::Print;
+
+ if (@ARGV < 1) {
+         print "Usage: $0 marc_leader\n";
+         exit 1;
+ }
+ my $marc_leader = $ARGV[0];
+
+ # Object.
+ my $obj = MARC::Leader->new;
+
+ # Parse.
+ my $leader_obj = $obj->parse($marc_leader);
+
+ # Print to output.
+ print scalar MARC::Leader::Print->new->print($leader_obj), "\n";
+
+ # Output for '02200cem a2200541 i 4500':
+ # Record length: 2200
+ # Record status: Corrected or revised
+ # Type of record: Cartographic material
+ # Bibliographic level: Monograph/Item
+ # Type of control: No specified type
+ # Character coding scheme: UCS/Unicode
+ # Indicator count: Number of character positions used for indicators
+ # Subfield code count: Number of character positions used for a subfield code (2)
+ # Base address of data: 541
+ # Encoding level: Full level
+ # Descriptive cataloging form: ISBD punctuation included
+ # Multipart resource record level: Not specified or not applicable
+ # Length of the length-of-field portion: Number of characters in the length-of-field portion of a Directory entry (4)
+ # Length of the starting-character-position portion: Number of characters in the starting-character-position portion of a Directory entry (5)
+ # Length of the implementation-defined portion: Number of characters in the implementation-defined portion of a Directory entry (0)
+ # Undefined: Undefined
+
+=head1 EXAMPLE3
+
 =for comment filename=serialize_marc_leader.pl
 
  use strict;
@@ -275,6 +318,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
